@@ -1,9 +1,9 @@
 package Net::Twitter::API;
 {
-  $Net::Twitter::API::VERSION = '4.00007';
+  $Net::Twitter::API::VERSION = '4.01000';
 }
 use Moose ();
-use Carp::Clan qw/^Net::Twitter/;
+use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use Moose::Exporter;
 use URI::Escape;
 use DateTime::Format::Strptime;
@@ -119,10 +119,10 @@ sub twitter_api_method {
 
 package Net::Twitter::Meta::Method;
 {
-  $Net::Twitter::Meta::Method::VERSION = '4.00007';
+  $Net::Twitter::Meta::Method::VERSION = '4.01000';
 }
 use Moose;
-use Carp::Clan qw/^Net::Twitter/;
+use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 extends 'Moose::Meta::Method';
 
 use namespace::autoclean;
@@ -166,7 +166,7 @@ Net::Twitter::API - Moose sugar for defining Twitter API methods
 
 =head1 VERSION
 
-version 4.00007
+version 4.01000
 
 =head1 SYNOPSIS
 
