@@ -1,9 +1,9 @@
 package Net::Twitter::Role::API::REST;
 {
-  $Net::Twitter::Role::API::REST::VERSION = '4.00007';
+  $Net::Twitter::Role::API::REST::VERSION = '4.01000';
 }
 use Moose::Role;
-use Carp::Clan qw/^Net::Twitter/;
+use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use Net::Twitter::API;
 use DateTime::Format::Strptime;
 use URI;
@@ -1739,7 +1739,7 @@ Net::Twitter::Role::API::REST - A definition of the Twitter REST API as a Moose
 
 =head1 VERSION
 
-version 4.00007
+version 4.01000
 
 =head1 SYNOPSIS
 
